@@ -6,7 +6,7 @@ use crate::{
         messages::{traits::ReadLengthPrefix, MessageData, NetworkMessage, ProcessMessage},
         send_message,
     },
-    Block, BlockChain, BlockChainBase, Event, UserPair,
+    Block, BlockChainBase, Event, UserPair,
 };
 
 use std::future::Future;
@@ -59,9 +59,7 @@ pub async fn initial_lookup<T: 'static + BlockChainBase>(
         pair.node.account.role,
     ));
 
-    send_message(&mut stream, reg_message).await?;
-
-    debug!("Sent Reg Message");
+    send_message(&mut stream, &reg_message).await?;
 
     if matches!(
         NetworkMessage::<T>::from_stream(&mut stream, &mut buffer)
@@ -75,14 +73,10 @@ pub async fn initial_lookup<T: 'static + BlockChainBase>(
             pair.node.account.profile.lookup_filter,
         ));
 
-        send_message(&mut stream, gen_req).await?;
-
-        debug!("Sent Message");
+        send_message(&mut stream, &gen_req).await?;
 
         let read_in = NetworkMessage::<T>::from_stream(&mut stream, &mut buffer).await?;
 
-        debug!("Read Message");
-
         match read_in.data {
             MessageData::PeerAddresses(addrs) => {
                 // Iterate over addresses and create connection requests
@@ -105,9 +99,7 @@ pub async fn initial_lookup<T: 'static + BlockChainBase>(
     }
 
     let finish_message = NetworkMessage::<T>::new(MessageData::Finish);
-    send_message(&mut stream, finish_message).await?;
-
-    debug!("FINISHED INITIAL LOOKUP");
+    send_message(&mut stream, &finish_message).await?;
 
     Ok(())
 }
@@ -119,10 +111,15 @@ pub async fn initial_lookup<T: 'static + BlockChainBase>(
 /// its database.
 async fn general_lookup<T: 'static + BlockChainBase>(
     pair: Arc<UserPair<T>>,
-    address: String,
+    lookup_address: Option<String>,
 ) -> Result<()> {
     let mut buffer = [0_u8; 4096];
-    debug!("GENERAL LOOKUP");
+
+    let address = match lookup_address {
+        Some(a) => a,
+        None => return Err(Error::msg("No LookUp Address")),
+    };
+
     debug!("Creating LookUp Connection with: {}", address);
     // Open connection
     let mut stream: TcpStream = TcpStream::connect(address).await?;
@@ -133,14 +130,10 @@ async fn general_lookup<T: 'static + BlockChainBase>(
         pair.node.account.profile.lookup_filter,
     ));
 
-    send_message(&mut stream, gen_req).await?;
-
-    debug!("Sent Message");
+    send_message(&mut stream, &gen_req).await?;
 
     let read_in = NetworkMessage::<T>::from_stream(&mut stream, &mut buffer).await?;
 
-    debug!("Read Message");
-
     match read_in.data {
         MessageData::PeerAddresses(addrs) => {
             // Iterate over addresses and create connection requests
@@ -157,31 +150,28 @@ async fn general_lookup<T: 'static + BlockChainBase>(
         }
         MessageData::NoAddr => {
             let finish_message = NetworkMessage::<T>::new(MessageData::Finish);
-            send_message(&mut stream, finish_message).await?;
+            send_message(&mut stream, &finish_message).await?;
             return Err(Error::msg("No addresses in the lookup table"));
         }
         _ => unreachable!(),
     }
 
     let finish_message = NetworkMessage::<T>::new(MessageData::Finish);
-    send_message(&mut stream, finish_message).await?;
+    send_message(&mut stream, &finish_message).await?;
 
     Ok(())
 }
 
 /// Connects to the lookup server and sends a [`Strike`] message
 async fn lookup_strike<T: 'static + BlockChainBase>(address: String, conn_id: u128) -> Result<()> {
-    debug!("SENDING STRIKE");
-    debug!("Creating LookUp Connection with: {}", address);
+    debug!("Sending Strike to: {}", address);
     // Open connection
     let mut stream: TcpStream = TcpStream::connect(address).await?;
 
     // Create general request message and send over stream
     let gen_req = NetworkMessage::<T>::new(MessageData::Strike(conn_id));
 
-    send_message(&mut stream, gen_req).await?;
-
-    debug!("Sent Message");
+    send_message(&mut stream, &gen_req).await?;
 
     Ok(())
 }
@@ -194,14 +184,13 @@ pub async fn clear_connection_pool<T: 'static + BlockChainBase + Send>(
     let size = cp_buffer_write.len();
     let mut map_write = connect_pool.map.write().await;
 
-    debug!("CLEARING CONNECTION POOL");
+    debug!("Removing dead connections from ConnectionPool");
     while let Some(id) = cp_buffer_write.pop() {
-        debug!("REMOVING: {}", &id);
         // Remove item from connection pool
         map_write.remove(&id);
         // Send strike message to lookup
-        if let Some(addr) = pair.node.account.profile.lookup_address.clone() {
-            lookup_strike::<T>(addr, id).await?;
+        if let Some(addr) = &pair.node.account.profile.lookup_address {
+            lookup_strike::<T>(String::from(addr), id).await?;
         }
     }
 
@@ -209,51 +198,6 @@ pub async fn clear_connection_pool<T: 'static + BlockChainBase + Send>(
     Ok(())
 }
 
-/// Given an address and port, creates connection with new node
-///
-/// Function is passed an address and a port and it will attempt to
-/// create a TCP connection with the node at that address
-async fn create_connection<T: BlockChainBase>(
-    pair: Arc<UserPair<T>>,
-    address: String,
-    connect_pool: Arc<ConnectionPool>,
-) -> Result<()> {
-    debug!("Creating Connection with: {}", address);
-    // Open connection
-    let mut stream: TcpStream = TcpStream::connect(address).await?;
-
-    // Send initial message with ID
-    let send_mess = NetworkMessage::<T>::new(MessageData::InitialID(
-        pair.node.account.id,
-        pair.node.account.pub_key.clone(),
-        pair.node.account.role,
-    ));
-    send_message(&mut stream, send_mess).await?;
-
-    // Recv initial message with ID
-    let (id, pub_key, role) = match initial_stream_handler::<T>(&mut stream).await {
-        Some((id, pub_key, role)) => (id, pub_key, role),
-        _ => return Err(Error::msg("Error getting initial data Message")),
-    };
-
-    // Transmit initial bc state
-    let bc_read = pair.node.blockchain.read().await;
-    let bc_mess = NetworkMessage::<T>::new(MessageData::State(bc_read.clone()));
-    send_message(&mut stream, bc_mess).await?;
-
-    // Add to map
-    match connect_pool
-        .add(Connection::new(stream, role, Some(pub_key)), id)
-        .await
-    {
-        Ok(_) => {
-            pair.sync.cp_size.fetch_add(1, Ordering::SeqCst);
-            Ok(())
-        }
-        Err(e) => Err(e),
-    }
-}
-
 /// Takes in [`NetworkMessage`] and sends it to all intended recipients
 ///
 /// Gets a [`NetworkMessage`] and either floods all connections with the message
@@ -263,7 +207,6 @@ async fn send_all<T: BlockChainBase>(
     message: NetworkMessage<T>,
     connect_pool: Arc<ConnectionPool>,
 ) -> Result<()> {
-    debug!("Sending message to all connected participants");
     let conn_map = connect_pool.map.read().await;
     for (id, conn) in conn_map.iter() {
         let tcp = conn.get_tcp();
@@ -271,13 +214,13 @@ async fn send_all<T: BlockChainBase>(
 
         debug!("Sending message to: {:?}", tcp.addr);
 
-        match send_message(stream.deref_mut(), message.clone()).await {
+        match send_message(stream.deref_mut(), &message).await {
             Ok(_) => Ok(()),
             Err(e) => {
-                error!("ERROR SENDING TO: {}", id);
+                error!("Error sending message to: {}", id);
                 pair.sync.cp_clear.store(true, Ordering::SeqCst);
                 let mut cp_buffer_cpy = pair.sync.cp_buffer.write().await;
-                cp_buffer_cpy.push(id.clone());
+                cp_buffer_cpy.push(*id);
                 Err(e)
             }
         }?;
@@ -331,12 +274,12 @@ async fn process_connection<T: 'static + BlockChainBase>(
         pair.node.account.pub_key.clone(),
         pair.node.account.role,
     ));
-    send_message(&mut stream, send_mess).await?;
+    send_message(&mut stream, &send_mess).await?;
 
     // Transmit initial bc state
     let bc_read = pair.node.blockchain.read().await;
     let bc_mess = NetworkMessage::<T>::new(MessageData::State(bc_read.clone()));
-    send_message(&mut stream, bc_mess).await?;
+    send_message(&mut stream, &bc_mess).await?;
 
     let conn = Connection::new(stream, role, Some(pub_key));
     match connect_pool.add(conn, id).await {
@@ -362,6 +305,51 @@ async fn initial_stream_handler<T: BlockChainBase>(
     }
 }
 
+/// Given an address and port, creates connection with new node
+///
+/// Function is passed an address and a port and it will attempt to
+/// create a TCP connection with the node at that address
+async fn create_connection<T: BlockChainBase>(
+    pair: Arc<UserPair<T>>,
+    address: String,
+    connect_pool: Arc<ConnectionPool>,
+) -> Result<()> {
+    debug!("Creating Connection with: {}", address);
+    // Open connection
+    let mut stream: TcpStream = TcpStream::connect(address).await?;
+
+    // Send initial message with ID
+    let send_mess = NetworkMessage::<T>::new(MessageData::InitialID(
+        pair.node.account.id,
+        pair.node.account.pub_key.clone(),
+        pair.node.account.role,
+    ));
+    send_message(&mut stream, &send_mess).await?;
+
+    // Recv initial message with ID
+    let (id, pub_key, role) = match initial_stream_handler::<T>(&mut stream).await {
+        Some((id, pub_key, role)) => (id, pub_key, role),
+        _ => return Err(Error::msg("Error getting initial data Message")),
+    };
+
+    // Transmit initial bc state
+    let bc_read = pair.node.blockchain.read().await;
+    let bc_mess = NetworkMessage::<T>::new(MessageData::State(bc_read.clone()));
+    send_message(&mut stream, &bc_mess).await?;
+
+    // Add to map
+    match connect_pool
+        .add(Connection::new(stream, role, Some(pub_key)), id)
+        .await
+    {
+        Ok(_) => {
+            pair.sync.cp_size.fetch_add(1, Ordering::SeqCst);
+            Ok(())
+        }
+        Err(e) => Err(e),
+    }
+}
+
 /// Goes through each [`Connection`] and checks to see if they contain a [`NetworkMessage`]
 ///
 /// Goes through all connections and checks if they have sent anything. If the stream is shutdown
@@ -461,26 +449,23 @@ pub async fn outgoing_connections<T: 'static + BlockChainBase>(
         if num_conns == 0 && pair.node.account.profile.lookup_address.is_some() {
             match general_lookup(
                 Arc::clone(&pair),
-                pair.node.account.profile.lookup_address.clone().unwrap(),
+                pair.node.account.profile.lookup_address.clone(),
             )
             .await
             {
                 Ok(_) => (),
                 Err(e) => {
-                    error!("GENERAL LOOKUP FAILED: {}", e);
+                    error!("General LookUp failed: {}", e);
                     sleep(Duration::from_millis(10000)).await;
                 }
             };
         }
 
-        info!("CHECKING PERMIT");
         // Wait until there is something in the pipeline
         pair.sync.claim_permit().await;
-        info!("CLAIMED PERMIT");
 
         let num_conns: usize = pair.sync.cp_size.load(Ordering::SeqCst);
 
-        debug!("NUMBER OF CONNS: {}", num_conns);
         // Read pipeline for s
         let mut rx = pair.sync.outbound_channel.1.write().await;
         // When new message comes through pipeline
@@ -495,7 +480,7 @@ pub async fn outgoing_connections<T: 'static + BlockChainBase>(
                     // TODO: If Miner, and event is being sent, add it to block queue
                     if num_conns == 0 {
                         debug!("No connections, so adding to unsent queue");
-                        unsent_q.push(m.clone());
+                        unsent_q.push(m);
                         continue;
                     }
                     match send_all(
@@ -505,8 +490,8 @@ pub async fn outgoing_connections<T: 'static + BlockChainBase>(
                     )
                     .await
                     {
-                        Ok(_) => debug!("MESSAGE SENDING SUCCESS"),
-                        Err(e) => error!("MESSAGE SENDING ERROR: {}", e),
+                        Ok(_) => debug!("Message sent successfully"),
+                        Err(e) => error!("Error sending message: {}", e),
                     };
                 }
                 ProcessMessage::NewConnection(id, addr) => {
@@ -517,14 +502,12 @@ pub async fn outgoing_connections<T: 'static + BlockChainBase>(
                     )
                     .await
                     {
-                        Ok(_) => debug!("CONNECTION CREATION SUCCESS"),
+                        Ok(_) => debug!("Created a new Connection"),
                         Err(e) => {
-                            if let Some(lookup_addr) =
-                                pair.node.account.profile.lookup_address.clone()
-                            {
-                                lookup_strike::<T>(lookup_addr, id.clone()).await?;
+                            if let Some(lookup_addr) = &pair.node.account.profile.lookup_address {
+                                lookup_strike::<T>(String::from(lookup_addr), *id).await?;
                             }
-                            error!("CONNECTION CREATION FAILED: {}", e)
+                            error!("Failed to create a new Connection: {}", e)
                         }
                     }
                 }
@@ -578,7 +561,6 @@ where
                 .await?
             } else {
                 // Sleep for a moment (10 seconds?)
-                debug!("NO CONNECTIONS");
                 sleep(Duration::from_millis(1000)).await;
             }
         }
@@ -588,25 +570,6 @@ where
     Ok(())
 }
 
-/// Function to replace the [`BlockChain`] in [`UserPair`]
-pub async fn replace_blockchain<T: 'static + BlockChainBase + std::marker::Sync>(
-    pair: Arc<UserPair<T>>,
-    bc: &BlockChain<T>,
-) -> Result<()> {
-    info!("New blockchain received, old Blockchain replaced");
-    let mut bc_unlocked = pair.node.blockchain.write().await;
-
-    // Set new save blockchain location to one of previous blockchain
-    let mut new_bc = bc.clone();
-    new_bc.set_save_location(bc_unlocked.save_location());
-
-    // Save new blockchain
-    *bc_unlocked = new_bc;
-    bc_unlocked.save()?;
-
-    Ok(())
-}
-
 /// Function to add a new [`Block`] to [`BlockChain`]
 pub async fn add_block<T: 'static + BlockChainBase + std::marker::Sync>(
     pair: Arc<UserPair<T>>,
@@ -661,8 +624,14 @@ where
     info!("Participant Address: {:?}", &inbound_addr);
 
     // Talk to LookUp Server and get initial connections
-    if let Some(addr) = pair.node.account.profile.lookup_address.clone() {
-        match initial_lookup(Arc::clone(&pair), addr, inbound_addr.to_string()).await {
+    if let Some(addr) = &pair.node.account.profile.lookup_address {
+        match initial_lookup(
+            Arc::clone(&pair),
+            String::from(addr),
+            inbound_addr.to_string(),
+        )
+        .await
+        {
             Ok(_) => debug!("Initial Lookup Success"),
             Err(e) => error!("Initial Lookup Error: {}", e),
         };
